#ifndef NT2_INCLUDE_CONSTANTS_ALLBITS_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_ALLBITS_HPP_INCLUDED

#include <nt2/constant/include/constants/allbits.hpp>

#endif
